@@ -10,7 +10,7 @@ use Hash::Subset qw(hash_subset);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-09-27'; # DATE
 our $DIST = 'App-BrowserUtils'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our %SPEC;
 
@@ -163,8 +163,14 @@ our %argopt_quiet = (
 
 our %argopt_periods = (
     periods => {
+        'x.name.is_plural' => 1,
+        'x.name.singular' => 'period',
         summary => 'Pause and unpause times, in seconds',
-        schema => ['array*', of=>'duration', min_len=>2, 'x.perl.coerce_rules'=>['From_str::comma_sep']],
+        schema => ['array*', {
+            of=>'duration',
+            min_len=>2,
+            #'x.perl.coerce_rules'=>['From_str::comma_sep'], # not working yet
+        }],
         description => <<'_',
 
 For example, to pause for 5 minutes, then unpause 10 seconds, then pause for 2
@@ -696,7 +702,7 @@ App::BrowserUtils - Utilities related to browsers, particularly modern GUI ones
 
 =head1 VERSION
 
-This document describes version 0.014 of App::BrowserUtils (from Perl distribution App-BrowserUtils), released on 2021-09-27.
+This document describes version 0.015 of App::BrowserUtils (from Perl distribution App-BrowserUtils), released on 2021-09-27.
 
 =head1 SYNOPSIS
 
